@@ -87,8 +87,8 @@ typedef struct xine_video_port_s xine_video_port_t;
 
 #ifndef XINE_DISABLE_DEPRECATED_FEATURES
 /* convenience types: simple player UIs might want to call ports drivers */
-typedef xine_audio_port_t xine_ao_driver_t;
-typedef xine_video_port_t xine_vo_driver_t;
+typedef xine_audio_port_t xine_ao_driver_t XINE_DEPRECATED;
+typedef xine_video_port_t xine_vo_driver_t XINE_DEPRECATED;
 #endif
 
 
@@ -111,8 +111,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   12
-#define XINE_VERSION       "1.1.12"
+#define XINE_SUB_VERSION   16
+#define XINE_VERSION       "1.1.16.2"
 
 /*
  * pre-init the xine engine
@@ -258,7 +258,7 @@ int  xine_play (xine_stream_t *stream, int start_pos, int start_time) XINE_PROTE
  *
  * returns 1 if OK, 0 on error (use xine_get_error for details)
  */
-int  xine_trick_mode (xine_stream_t *stream, int mode, int value) XINE_PROTECTED;
+int  xine_trick_mode (xine_stream_t *stream, int mode, int value) XINE_PROTECTED XINE_DEPRECATED;
 
 /* trick modes */
 #define XINE_TRICK_MODE_OFF                0
@@ -429,8 +429,13 @@ int  xine_get_param (xine_stream_t *stream, int param) XINE_PROTECTED;
  * image data into a too small buffer.
  *
  * xine_get_current_frame_alloc() takes care of allocating
- * a buffer on it's own, so image data can be retrieved by
+ * a buffer on its own, so image data can be retrieved by
  * a single call without the need to pause the stream.
+ * 
+ * xine_get_current_frame_data() passes the parameters of the
+ * previously mentioned functions plus further information in
+ * a structure and can work like the _s or _alloc function
+ * respectively depending on the passed flags.
  *
  * all functions return 1 on success, 0 failure.
  */
@@ -442,12 +447,33 @@ int  xine_get_current_frame (xine_stream_t *stream,
 int  xine_get_current_frame_s (xine_stream_t *stream,
 			     int *width, int *height,
 			     int *ratio_code, int *format,
-			     uint8_t *img, int *size) XINE_PROTECTED;
+			     uint8_t *img, int *img_size) XINE_PROTECTED;
 
 int  xine_get_current_frame_alloc (xine_stream_t *stream,
 			     int *width, int *height,
 			     int *ratio_code, int *format,
-			     uint8_t **img, int *size) XINE_PROTECTED;
+			     uint8_t **img, int *img_size) XINE_PROTECTED;
+
+typedef struct {
+
+  int      width;
+  int      height;
+  int      crop_left;
+  int      crop_right;
+  int      crop_top;
+  int      crop_bottom;
+  int      ratio_code;
+  int      interlaced;
+  int      format;
+  int      img_size;
+  uint8_t *img;
+} xine_current_frame_data_t;
+
+#define XINE_FRAME_DATA_ALLOCATE_IMG (1<<0)
+
+int  xine_get_current_frame_data (xine_stream_t *stream,
+			     xine_current_frame_data_t *data,
+			     int flags) XINE_PROTECTED;
 
 /* xine image formats */
 #define XINE_IMGFMT_YV12 (('2'<<24)|('1'<<16)|('V'<<8)|'Y')
@@ -537,7 +563,7 @@ int xine_get_video_frame (xine_stream_t *stream,
 			  int *ratio_code, 
 			  int *duration, /* msec */
 			  int *format,
-			  uint8_t *img) XINE_PROTECTED;
+			  uint8_t *img) XINE_PROTECTED XINE_DEPRECATED;
 
 /* TODO: xine_get_audio_frame */
 
@@ -964,6 +990,7 @@ const char *xine_get_meta_info   (xine_stream_t *stream, int info) XINE_PROTECTE
 #define XINE_META_INFO_INPUT_PLUGIN        9
 #define XINE_META_INFO_CDINDEX_DISCID      10
 #define XINE_META_INFO_TRACK_NUMBER        11
+#define XINE_META_INFO_COMPOSER            12
 
 
 /*********************************************************************
@@ -1095,7 +1122,7 @@ void xine_plugins_garbage_collector(xine_t *self) XINE_PROTECTED;
 #ifndef XINE_DISABLE_DEPRECATED_FEATURES
 /* talk to video output driver - old method */
 int    xine_gui_send_vo_data (xine_stream_t *self,
-			      int type, void *data) XINE_PROTECTED;
+			      int type, void *data) XINE_PROTECTED XINE_DEPRECATED;
 #endif
 
 /* new (preferred) method to talk to video driver. */
@@ -1130,7 +1157,7 @@ typedef struct {
    *
    * this will be called by the video driver to find out
    * how big the video output area size will be for a
-   * given video size. The ui should _not_ adjust it's
+   * given video size. The ui should _not_ adjust its
    * video out area, just do some calculations and return
    * the size. This will be called for every frame, ui
    * implementation should be fast.
@@ -1154,12 +1181,12 @@ typedef struct {
    * frame output callback
    *
    * this will be called by the video driver for every frame
-   * it's about to draw. ui can adapt it's size if necessary
+   * it's about to draw. ui can adapt its size if necessary
    * here.
    * note: the ui doesn't have to adjust itself to this
    * size, this is just to be taken as a hint.
    * ui must return the actual size of the video output
-   * area and the video output driver will do it's best
+   * area and the video output driver will do its best
    * to adjust the video frames to that size (while
    * preserving aspect ratio and stuff).
    *    dest_x, dest_y: offset inside window
@@ -1230,7 +1257,7 @@ typedef struct {
    *
    * this will be called by the video driver to find out
    * how big the video output area size will be for a
-   * given video size. The ui should _not_ adjust it's
+   * given video size. The ui should _not_ adjust its
    * video out area, just do some calculations and return
    * the size. This will be called for every frame, ui
    * implementation should be fast.
@@ -1254,12 +1281,12 @@ typedef struct {
    * frame output callback
    *
    * this will be called by the video driver for every frame
-   * it's about to draw. ui can adapt it's size if necessary
+   * it's about to draw. ui can adapt its size if necessary
    * here.
    * note: the ui doesn't have to adjust itself to this
    * size, this is just to be taken as a hint.
    * ui must return the actual size of the video output
-   * area and the video output driver will do it's best
+   * area and the video output driver will do its best
    * to adjust the video frames to that size (while
    * preserving aspect ratio and stuff).
    *    dest_x, dest_y: offset inside window
@@ -1311,15 +1338,12 @@ typedef struct {
   void *user_data;
 
   /* OR'ed frame_format
-   * a frontend must at least support rgb
-   * a frontend supporting yuv must support both yv12 and yuy2
-   * then possible combinations are:
-   *   XINE_VORAW_RGB                 ( rgb )
-   *   XINE_VORAW_YV12|XINE_VORAW_YUY2|XINE_VORAW_RGB   ( yv12, yuy2 and rgb )
-   *
+   * Unsupported frame formats are converted to rgb.
+   * XINE_VORAW_RGB is always assumed by the driver, even if not set.
+   * So a frontend must at least support rgb.
    * Be aware that rgb requires more cpu than yuv,
    * so avoid its usage for video playback.
-   * However, it's usefull for single frame capture (e.g. thumbs)
+   * However, it's useful for single frame capture (e.g. thumbs)
    */
   int supported_formats;
 
@@ -1618,7 +1642,7 @@ int  xine_config_lookup_entry (xine_t *self, const char *key,
 /*
  * update a config entry (which was returned from lookup_entry() )
  *
- * xine will make a deep copy of the data in the entry into it's internal
+ * xine will make a deep copy of the data in the entry into its internal
  * config database.
  */
 void xine_config_update_entry (xine_t *self,
@@ -1762,6 +1786,7 @@ void xine_config_reset (xine_t *self) XINE_PROTECTED;
 #define XINE_EVENT_VDR_SELECTAUDIO      352
 #define XINE_EVENT_VDR_TRICKSPEEDMODE   353
 #define XINE_EVENT_VDR_PLUGINSTARTED    354
+#define XINE_EVENT_VDR_DISCONTINUITY    355
 
 /* events generated from post plugins */
 #define XINE_EVENT_POST_TVTIME_FILMMODE_CHANGE   400
@@ -1890,7 +1915,7 @@ typedef struct {
 typedef struct {
   int                 alternative; /* alternative playlist number, usually 0 */
   char                mrl[1]; /* might (will) be longer */
-} xine_mrl_reference_data_t;
+} xine_mrl_reference_data_t XINE_DEPRECATED;
 
 typedef struct {
   int                 alternative; /* as above */
@@ -2013,8 +2038,8 @@ typedef struct {
  * This is the mechanism to report async errors from engine.
  *
  * If frontend knows about the XINE_MSG_xxx type it may safely 
- * ignore the 'explanation' field and provide it's own custom
- * dialog to the 'parameters'.
+ * ignore the 'explanation' field and provide its own custom
+ * dialogue to the 'parameters'.
  *
  * right column specifies the usual parameters.
  */
@@ -2192,16 +2217,16 @@ void        xine_osd_free          (xine_osd_t *self) XINE_PROTECTED;
 typedef enum {
 	XINE_TVSYSTEM_PAL = 0,
 	XINE_TVSYSTEM_NTSC
-} xine_tvsystem;
+} xine_tvsystem XINE_DEPRECATED;
 
 /* connect to nvtvd server and save current TV and X settings */
-int xine_tvmode_init (xine_t *self) XINE_PROTECTED;
+int xine_tvmode_init (xine_t *self) XINE_PROTECTED XINE_DEPRECATED;
 
 /* Turn tvmode on/off (1/0)*/
-int xine_tvmode_use(xine_t *self, int use_tvmode) XINE_PROTECTED;
+int xine_tvmode_use(xine_t *self, int use_tvmode) XINE_PROTECTED XINE_DEPRECATED;
 
 /* Set which tv system to use: XINE_TVSYSTEM_PAL or XINE_TVSYSTEM_NTSC */
-void xine_tvmode_set_tvsystem(xine_t *self, xine_tvsystem system) XINE_PROTECTED;
+void xine_tvmode_set_tvsystem(xine_t *self, xine_tvsystem system) XINE_PROTECTED XINE_DEPRECATED;
 
 /* try to change TV state if enabled
  *   type select 'regular' (0) or 'TV' (1) state
@@ -2210,16 +2235,16 @@ void xine_tvmode_set_tvsystem(xine_t *self, xine_tvsystem system) XINE_PROTECTED
  *   fps frame rate the mode should match best or 0 if unknown
  * returns: finally selected state
  */
-int xine_tvmode_switch (xine_t *self, int type, int width, int height, double fps) XINE_PROTECTED;
+int xine_tvmode_switch (xine_t *self, int type, int width, int height, double fps) XINE_PROTECTED XINE_DEPRECATED;
 
 /* adapt (maximum) output size to visible area if necessary and return pixel
  * aspect and real frame rate if available
  */
 void xine_tvmode_size (xine_t *self, int *width, int *height,
-		       double *pixelratio, double *fps) XINE_PROTECTED;
+		       double *pixelratio, double *fps) XINE_PROTECTED XINE_DEPRECATED;
 
 /* restore old TV and X settings and close nvtvd connection */
-void xine_tvmode_exit (xine_t *self) XINE_PROTECTED;
+void xine_tvmode_exit (xine_t *self) XINE_PROTECTED XINE_DEPRECATED;
 
 #endif
 
